@@ -17,8 +17,9 @@ use Lingua::PTD::Dumper;
 use Lingua::PTD::BzDmp;
 use Lingua::PTD::XzDmp;
 use Lingua::PTD::SQLite;
+use Lingua::PTD::TSV;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 =encoding UTF-8
 
@@ -609,7 +610,7 @@ sub downtr {
                 $self->_delete_word($word)
             } else {
                 $self->_update_word($word, $res);
-            }			
+            }
         }
 
         $counter ++;
@@ -673,7 +674,7 @@ true value in success.
 =cut
 
 sub saveAs {
-    my ($self, $type, $filename) = @_;
+    my ($self, $type, $filename, $extra) = @_;
 
     warn "Lingua::PTD saveAs called without all required parameteres" unless $type && $filename;
 
@@ -683,6 +684,7 @@ sub saveAs {
     Lingua::PTD::BzDmp::_save( $self => $filename) and $done = 1 if $type =~ /bz2/i;
     Lingua::PTD::XzDmp::_save( $self => $filename) and $done = 1 if $type =~ /xz/i;
     Lingua::PTD::SQLite::_save($self => $filename) and $done = 1 if $type =~ /sqlite/i;
+    Lingua::PTD::TSV::_save($self, $filename, $extra) and $done = 1 if $type =~ /tsv/i;
     # XXX - add above in the documentation.
 
     # default
@@ -897,6 +899,8 @@ sub ucts {
     else {
         return [@final];
     }
+
+    close STDOUT if $output;
 }
 
 sub __build_ucts {
@@ -1021,13 +1025,15 @@ sub bws {
 
     my @words = $ptd->words;
     foreach my $word (@words) {
-        my $count = $ptd->count($_);
+        my $count = $ptd->count($word);
         next unless ($count >= $min_occur);
+        next if ($word eq "(none)"); 
 
         my %transHash = $ptd->transHash($word);
         foreach (keys %transHash) {
             my $p = $transHash{$_};
             next unless ($p >= $prob);
+            next if ($_ eq "(none)"); 
 
             __pp_ucts({l=>[$word],r=>[$_],rank=>$p}, $rank) if $pp;
             push @final, {l=>$word, r=>$_, rank=>$p} unless $pp;
@@ -1035,20 +1041,22 @@ sub bws {
     }
     @words = $ptd_inv->words;
     foreach my $word (@words) {
-        my $count = $ptd->count($_);
+        my $count = $ptd_inv->count($word);
         next unless ($count >= $min_occur);
+        next if ($word eq "(none)"); 
 
-        my %transHash = $ptd->transHash($word);
+        my %transHash = $ptd_inv->transHash($word);
         foreach (keys %transHash) {
             my $p = $transHash{$_};
             next unless ($p >= $prob);
+            next if ($_ eq "(none)"); 
 
             __pp_ucts({l=>[$_],r=>[$word],rank=>$p}, $rank) if $pp;
             push @final, {l=>$_, r=>$word, rank=>$p} unless $pp;
         }
     }
 
-    close STDOUT;
+    close STDOUT if $output;
     return [@final] unless $pp;
 }
 
